@@ -53,6 +53,7 @@ def sigint_handler(signal, frame):
 
     if _ctrl_c > 1:
         raise KeyboardInterrupt()
+
     if top():
         top().terminate(result=Error, reason="KeyboardInterrupt")
 
@@ -209,11 +210,13 @@ def start_database_handler():
     handler = threading.Thread(target=database_handler)
     handler.name = 'tfs-database'
     handler.start()
-    _handlers.appen(handler)
+    _handlers.append(handler)
 
 def init():
     """Initialization before we run the first test.
     """
+    if threading.current_thread() is not threading.main_thread():
+        raise RuntimeError("top level test was not started in main thread")
     signal.signal(signal.SIGINT, sigint_handler)
     cleanup()
     start_output_handler()
