@@ -14,6 +14,7 @@
 # limitations under the License.
 import inspect
 import asyncio
+import concurrent
 
 from asyncio import *
 
@@ -35,3 +36,23 @@ def is_running_in_event_loop():
     except RuntimeError:
         pass
     return False
+
+class OptionalFuture(Future):
+    """Future that will not complain about any
+    exceptions not being retrieved.
+    """
+    def __del__(self):
+        return
+
+def wrap_future(future, *, loop=None, new_future=None):
+    """Wrap concurrent.futures.Future object."""
+    if isfuture(future):
+        return future
+    assert isinstance(future, concurrent.futures.Future), \
+        f'concurrent.futures.Future is expected, got {future!r}'
+    if loop is None:
+        loop = asyncio.events.get_event_loop()
+    if new_future is None:
+        new_future = loop.create_future()
+    asyncio.futures._chain_future(future, new_future)
+    return new_future
\ No newline at end of file
